#TADA analysis in R to generate Table2 and Table3
source("TADA.v.1.2.R") 
#TADA.v.1.2.R download from http://www.compgen.pitt.edu/TADA/TADA_homepage.htm
library(openxlsx)

#phenotype=c("ASD","SCZ","DD_ID","EE","CHD","TD","BP","OCD","CMS","All")
#Trios_number=c(10318,3402,202,973,31058,2645,909,219,118,184,50337)

#This is the example of ASD
phenotype=c("ASD")
number=c(10318)
phenotype_number=data.frame(cbind(phenotype,number),stringsAsFactors = FALSE)
phenotype_number$number=as.numeric(phenotype_number$number)
for (i in 1:dim(phenotype_number)[1]){
  tada.data=read.xlsx("TADA.xlsx",sheet=phenotype_number[i,1]) 
  #TADA.xlsx is the formated input of TADA which can be found in http://www.compgen.pitt.edu/TADA/TADA_guide.html
  n.family =phenotype_number[i,2]
  n = data.frame(dn=n.family, ca=NA, cn=NA)
  sample.counts <- list(cls1=n, cls2=n)
  cls1.counts=data.frame(dn=tada.data$dn.cls1, ca=NA, cn=NA)
  rownames(cls1.counts)=tada.data$gene.id
  cls2.counts=data.frame(dn=tada.data$dn.cls2, ca=NA, cn=NA)
  rownames(cls2.counts)=tada.data$gene.id
  tada.counts=list(cls1=cls1.counts,cls2=cls2.counts)
  mu=data.frame(cls1=tada.data$mut.cls1,cls2=tada.data$mut.cls2)
  denovo.only=data.frame(cls1=TRUE,cls2=TRUE)
  cls1= data.frame(gamma.mean.dn= 4.7,beta.dn=1,gamma.mean.CC=NA,beta.CC=NA ,rho1=NA,nu1=NA,rho0=NA,nu0=NA)
  cls2= data.frame(gamma.mean.dn= 20.0,beta.dn=1,gamma.mean.CC=NA,beta.CC=NA,rho1=NA,nu1=NA,rho0=NA,nu0=NA)
  hyperpar=list(cls1=cls1,cls2=cls2)
  re.TADA <- do.call(cbind.data.frame, TADA(tada.counts=tada.counts, sample.counts=sample.counts, mu=mu, hyperpar=hyperpar, denovo.only=denovo.only))
  re.TADA$qval=Bayesian.FDR(re.TADA$BF.total, pi0 = 0.95)
  re.TADA$Dmis=tada.data$dn.cls1
  re.TADA$LoF=tada.data$dn.cls2
  re.TADA.null=do.call(cbind.data.frame, TADAnull(tada.counts=tada.counts, sample.counts=sample.counts, mu=mu, hyperpar=hyperpar, denovo.only=denovo.only, nrep=100))
  re.TADA$pval=bayesFactor.pvalue(re.TADA$BF.total,re.TADA.null$BFnull.total)
  file_name=paste0(phenotype_number[i,1],".csv")
  write.csv(re.TADA,file=file_name)
}

#TADA Analyais for Figure2
files=list.files("./output_data_20201126/") #Sampling DNMs for each disorder
for (i in 1:length(files)){
  path=paste0("./output_data_20201126/",files[i])
  tada.data=read.table(path, header=T,sep = "\t") 
  n.family =as.numeric(strsplit(a,split = "_")[[1]][3])
  n = data.frame(dn=n.family, ca=NA, cn=NA)
  sample.counts <- list(cls1=n, cls2=n)
  cls1.counts=data.frame(dn=tada.data$dn.cls1, ca=NA, cn=NA)
  rownames(cls1.counts)=tada.data$gene.id
  cls2.counts=data.frame(dn=tada.data$dn.cls2, ca=NA, cn=NA)
  rownames(cls2.counts)=tada.data$gene.id
  tada.counts=list(cls1=cls1.counts,cls2=cls2.counts)
  mu=data.frame(cls1=tada.data$mut.cls1,cls2=tada.data$mut.cls2)
  denovo.only=data.frame(cls1=TRUE,cls2=TRUE)
  cls1= data.frame(gamma.mean.dn= 4.7,beta.dn=1,gamma.mean.CC=NA,beta.CC=NA ,rho1=NA,nu1=NA,rho0=NA,nu0=NA)
  cls2= data.frame(gamma.mean.dn= 20.0,beta.dn=1,gamma.mean.CC=NA,beta.CC=NA,rho1=NA,nu1=NA,rho0=NA,nu0=NA)
  hyperpar=list(cls1=cls1,cls2=cls2)
  re.TADA <- do.call(cbind.data.frame, TADA(tada.counts=tada.counts, sample.counts=sample.counts, mu=mu, hyperpar=hyperpar, denovo.only=denovo.only))
  re.TADA$qval=Bayesian.FDR(re.TADA$BF.total, pi0 = 0.95)
  #re.TADA$Dmis=tada.data$dn.cls1
  #re.TADA$LoF=tada.data$dn.cls2
  re.TADA.null=do.call(cbind.data.frame, TADAnull(tada.counts=tada.counts, sample.counts=sample.counts, mu=mu, hyperpar=hyperpar, denovo.only=denovo.only, nrep=100))
  re.TADA$pval=bayesFactor.pvalue(re.TADA$BF.total,re.TADA.null$BFnull.total)
  FDR_0.05_num= dim(subset(re.TADA,re.TADA$qval<0.05))[1]
  candidate_gene_number[i]=FDR_0.05_num 
}
  
sample_candidate_gene0=t(matrix(candidate_gene_number,nrow = length(phenotype),ncol = length(sampling)))
sample_candidate_gene=cbind(sampling,candidate_gene_number0)
write.csv(sample_candidate_gene,file = "sample_candidate_gene.csv")
